@@ -13,21 +13,10 @@
 
 #include <language/duchain/duchainlock.h>
 
-#include "pyport.h"
-#ifndef _WIN32
-#include "pyconfig.h"
-#endif
-#include "node.h"
-
 #include "Python.h"
 
-#include "Python-ast.h"
 #include "ast.h"
 
-#include "graminit.h"
-#include "grammar.h"
-#include "parsetok.h"
-
 #include "unicodeobject.h"
 
 #include "object.h"
